*-----------------------------------------*;  
* Author:      Kriss Harris               *;
* Email:       ITALJET125@YAHOO.COM       *;
* Description: Labelling Box Plot Part 2  *;
* Purpose:     Hands-On GTL - Part A      *;
*              SAS Global Forum 2017      *;
*	           794                        *;
*-----------------------------------------*;


* Setting up paths;
%macro start;
  %let a=%sysget(SAS_EXECFILEPATH);
  %let b=%sysget(SAS_EXECFILENAME);

  %global path;
  %let path= %sysfunc(tranwrd(&a,%str(exercises\)&b,%str(startup\setup.sas)));
  %put &path;
%mend;
%start;

%include "&path";
libname source "&inpath";

proc format;
  value trtfmt 0 = "Placebo"
              54 = "Xanomeline Low Dose"
			  81 = "Xanomeline High Dose";
run;

*---------------------------------------------------------------*;
*					    Datasets								*;	
*---------------------------------------------------------------*;

* ADLBC;
data adlbc_all;
  set source.adlbc;
  where param in ("Creatinine (umol/L)") and ablfl ne "Y";
run;

* ADSL - calculating number of subjects per group;
proc sql;
  create table bigN as
  select distinct trt01an, count(distinct usubjid) as bigN
  from source.adsl
  where saffl = "Y"
  group by trt01an;
quit;

proc sql;
  create table adlbc_all2 as
  select a.*, b.bigN, round(avg(a.aval), 0.1) as mean, round(std(a.aval), 0.01) as stddev
  from adlbc_all as a right join bigN as b
  on a.trtan = b.trt01an
  group by a.paramcd, a.trtan;
quit;

proc mixed data = adlbc_all2;
  class trtan;
  model aval = trtan;
  lsmeans trtan / diff=control("0");
run;

* Creating Figure;

proc template;
  define statgraph boxplot_template;
    begingraph;
	  layout overlay;
	    boxplot x = trtan y = aval / group = trtan groupdisplay = cluster;
        drawtext "Pr > |t|: 0.0003" / x = 25 y = 160 xspace = datapercent yspace = datavalue width = 30;
		drawtext "Pr > |t|: <0.0001" / x = 75 y = 160 xspace = datapercent yspace = datavalue width = 30;

		drawtext "3.86" / x = 25 y = 165 xspace = datapercent yspace = datavalue width = 30;
		drawtext "5.82" / x = 75 y = 165 xspace = datapercent yspace = datavalue width = 30;

      endlayout;
	endgraph;
  end;
run;

proc sort data = adlbc_all2;
  by param;
run;

ods listing gpath = "&outpath";
ods graphics / reset = all imagename = "boxplot_labelling2_solution";

proc sgrender data = adlbc_all2 template = boxplot_template;
  by param;
  format trtan trtfmt.;
run;

ods graphics / reset = all;
goptions reset = all;
